@@ -85,6 +85,31 @@ typedef enum
 	GTK_SOURCE_SMART_HOME_END_ALWAYS
 } GtkSourceSmartHomeEndType;
 
+/**
+ * GtkSourceDrawSpacesFlags:
+ * @GTK_SOURCE_DRAW_SPACES_SPACE: whether the space character should be drawn.
+ * @GTK_SOURCE_DRAW_SPACES_TAB: whether the tab character should be drawn.
+ * @GTK_SOURCE_DRAW_SPACES_NEWLINE: whether the line breaks should be drawn.
+ * @GTK_SOURCE_DRAW_SPACES_NBSP: whether the non-breaking whitespaces should be drawn.
+ * @GTK_SOURCE_DRAW_SPACES_ALL: wheter all kind of spaces should be drawn.
+ *
+ * GtkSourceDrawSpacesFlags determine what kind of spaces whould be drawn.
+ */
+/* TODO: it would be nice to have flags to specify to draw
+ * just leading/trailing whitespaces */
+typedef enum
+{
+	GTK_SOURCE_DRAW_SPACES_SPACE      = 1 << 0,
+	GTK_SOURCE_DRAW_SPACES_TAB        = 1 << 1,
+	GTK_SOURCE_DRAW_SPACES_NEWLINE    = 1 << 2,
+	GTK_SOURCE_DRAW_SPACES_NBSP       = 1 << 3,
+	GTK_SOURCE_DRAW_SPACES_ALL        = (GTK_SOURCE_DRAW_SPACES_SPACE   | \
+	                                     GTK_SOURCE_DRAW_SPACES_TAB     | \
+	                                     GTK_SOURCE_DRAW_SPACES_NEWLINE | \
+	                                     GTK_SOURCE_DRAW_SPACES_NBSP)
+} GtkSourceDrawSpacesFlags;
+
+
 GType		 gtk_source_view_get_type 		(void) G_GNUC_CONST;
 
 /* Constructors */
@@ -96,13 +121,13 @@ void 		 gtk_source_view_set_show_line_numbers 	(GtkSourceView   *view,
 							 gboolean         show);
 gboolean 	 gtk_source_view_get_show_line_numbers 	(GtkSourceView   *view);
 
-void 		 gtk_source_view_set_show_line_markers  (GtkSourceView   *view,
-							 gboolean         show);
-gboolean	 gtk_source_view_get_show_line_markers  (GtkSourceView   *view);
-
-void 		 gtk_source_view_set_tabs_width 	(GtkSourceView   *view,
+void 		 gtk_source_view_set_tab_width          (GtkSourceView   *view,
 							 guint            width);
-guint            gtk_source_view_get_tabs_width         (GtkSourceView   *view);
+guint            gtk_source_view_get_tab_width          (GtkSourceView   *view);
+
+void		 gtk_source_view_set_indent_width 	(GtkSourceView   *view,
+							 gint             width);
+gint		 gtk_source_view_get_indent_width	(GtkSourceView   *view);
 
 void		 gtk_source_view_set_auto_indent 	(GtkSourceView   *view,
 							 gboolean         enable);
@@ -114,10 +139,6 @@ void		 gtk_source_view_set_insert_spaces_instead_of_tabs
 gboolean	 gtk_source_view_get_insert_spaces_instead_of_tabs
 							(GtkSourceView   *view);
 
-void		 gtk_source_view_set_show_margin 	(GtkSourceView   *view,
-							 gboolean         show);
-gboolean 	 gtk_source_view_get_show_margin 	(GtkSourceView   *view);
-
 void		 gtk_source_view_set_indent_on_tab 	(GtkSourceView   *view,
 							 gboolean         enable);
 gboolean	 gtk_source_view_get_indent_on_tab 	(GtkSourceView   *view);
@@ -128,20 +149,54 @@ void		 gtk_source_view_set_highlight_current_line
 gboolean 	 gtk_source_view_get_highlight_current_line
 							(GtkSourceView   *view);
 
-void		 gtk_source_view_set_margin 		(GtkSourceView   *view,
-							 guint            margin);
-guint		 gtk_source_view_get_margin 		(GtkSourceView   *view);
+void		 gtk_source_view_set_show_right_margin 	(GtkSourceView   *view,
+							 gboolean         show);
+gboolean 	 gtk_source_view_get_show_right_margin 	(GtkSourceView   *view);
 
-void             gtk_source_view_set_marker_pixbuf      (GtkSourceView   *view,
-							 const gchar     *marker_type,
+void		 gtk_source_view_set_right_margin_position
+					 		(GtkSourceView   *view,
+							 guint            pos);
+guint		 gtk_source_view_get_right_margin_position
+					 		(GtkSourceView   *view);
+
+void 		 gtk_source_view_set_show_line_marks    (GtkSourceView   *view,
+							 gboolean         show);
+gboolean	 gtk_source_view_get_show_line_marks    (GtkSourceView   *view);
+
+void             gtk_source_view_set_mark_category_pixbuf
+							(GtkSourceView   *view,
+							 const gchar     *category,
 							 GdkPixbuf       *pixbuf);
-GdkPixbuf	*gtk_source_view_get_marker_pixbuf      (GtkSourceView   *view,
-				       			 const gchar     *marker_type);
+GdkPixbuf	*gtk_source_view_get_mark_category_pixbuf
+							(GtkSourceView   *view,
+				       			 const gchar     *category);
+
+void             gtk_source_view_set_mark_category_background
+							(GtkSourceView   *view,
+							 const gchar     *category,
+							 const GdkColor  *color);
+gboolean         gtk_source_view_get_mark_category_background
+							(GtkSourceView   *view,
+							 const gchar     *category,
+							 GdkColor        *dest);
+
+void             gtk_source_view_set_mark_category_priority
+							(GtkSourceView   *view,
+							 const gchar     *category,
+							 gint priority);
+gint		 gtk_source_view_get_mark_category_priority
+							(GtkSourceView   *view,
+				       			 const gchar     *category);
 
 void		 gtk_source_view_set_smart_home_end	(GtkSourceView             *view,
 							 GtkSourceSmartHomeEndType  smart_he);
 GtkSourceSmartHomeEndType
 		 gtk_source_view_get_smart_home_end	(GtkSourceView   *view);
 
+void		 gtk_source_view_set_draw_spaces	(GtkSourceView   *view,
+							 GtkSourceDrawSpacesFlags flags);
+GtkSourceDrawSpacesFlags
+		gtk_source_view_get_draw_spaces		(GtkSourceView   *view);
+
 G_END_DECLS
 #endif				/* end of SOURCE_VIEW_H__ */
